**********
Components
**********

.. automodule:: networkx.algorithms.components
.. currentmodule:: networkx

Connectivity
^^^^^^^^^^^^
.. automodule:: networkx.algorithms.components.connected
.. autosummary::
   :toctree: generated/

   is_connected
   number_connected_components
   connected_components
   connected_component_subgraphs
   node_connected_component

Strong connectivity
^^^^^^^^^^^^^^^^^^^
.. automodule:: networkx.algorithms.components.strongly_connected
.. autosummary::
   :toctree: generated/

   is_strongly_connected
   number_strongly_connected_components
   strongly_connected_components
   strongly_connected_component_subgraphs
   strongly_connected_components_recursive
   kosaraju_strongly_connected_components
   condensation


Weak connectivity
^^^^^^^^^^^^^^^^^
.. automodule:: networkx.algorithms.components.weakly_connected
.. autosummary::
   :toctree: generated/

   is_weakly_connected
   number_weakly_connected_components
   weakly_connected_components
   weakly_connected_component_subgraphs

Atrracting components
^^^^^^^^^^^^^^^^^^^^^
.. automodule:: networkx.algorithms.components.attracting
.. autosummary::
   :toctree: generated/

   is_attracting_component
   number_attracting_components
   attracting_components
   attracting_component_subgraphs





